diff --git a/tutorial/tutorialproblem_coupled.hh b/tutorial/tutorialproblem_coupled.hh
index ae26ab1e7ce058ba00774c4b8fac5e340010d0a8..ec4927dfb45e5acdad45936c5eba9dee60a7dc5d 100644
--- a/tutorial/tutorialproblem_coupled.hh
+++ b/tutorial/tutorialproblem_coupled.hh
@@ -142,13 +142,13 @@ public:
 
     //! Specifies which kind of boundary condition should be used for
     //! which equation for a finite volume on the boundary.
-    void boundaryTypes(BoundaryTypes &BCtypes, const Vertex &vertex) const
+    void boundaryTypes(BoundaryTypes &bcTypes, const Vertex &vertex) const
     {
-        const GlobalPosition &pos = vertex.geometry().center();
-        if (pos[0] < eps_) // Dirichlet conditions on left boundary
-           BCtypes.setAllDirichlet();
+        const GlobalPosition &globalPos = vertex.geometry().center();
+        if (globalPos[0] < eps_) // Dirichlet conditions on left boundary
+           bcTypes.setAllDirichlet();
         else // neuman for the remaining boundaries
-           BCtypes.setAllNeumann();
+           bcTypes.setAllNeumann();
 
     }
 
@@ -167,16 +167,16 @@ public:
     //! values mean influx.
     void neumann(PrimaryVariables &values,
                  const Element &element,
-                 const FVElementGeometry &fvElemGeom,
-                 const Intersection &isIt,
+                 const FVElementGeometry &fvGeometry,
+                 const Intersection &is,
                  int scvIdx,
                  int boundaryFaceIdx) const
     {
-        const GlobalPosition &pos =
-            fvElemGeom.boundaryFace[boundaryFaceIdx].ipGlobal;
+        const GlobalPosition &globalPos =
+            fvGeometry.boundaryFace[boundaryFaceIdx].ipGlobal;
         Scalar right = this->bboxMax()[0];
         // extraction of oil on the right boundary for approx. 1.e6 seconds
-        if (pos[0] > right - eps_) {
+        if (globalPos[0] > right - eps_) {
             // oil outflux of 30 g/(m * s) on the right boundary.
             values[Indices::contiWEqIdx] = 0;
             values[Indices::contiNEqIdx] = 3e-2;
@@ -191,7 +191,7 @@ public:
     //! method, the 'values' parameter stores primary variables.
     void initial(PrimaryVariables &values,
                  const Element &element,
-                 const FVElementGeometry &fvElemGeom,
+                 const FVElementGeometry &fvGeometry,
                  int scvIdx) const
     {
         values[Indices::pwIdx] = 200.0e3; // 200 kPa = 2 bar
@@ -204,7 +204,7 @@ public:
     //! in [kg / (m^3 * s)]. Positive values mean that mass is created.
     void source(PrimaryVariables &values,
                 const Element &element,
-                const FVElementGeometry &fvElemGeom,
+                const FVElementGeometry &fvGeometry,
                 int scvIdx) const
     {
         values[Indices::contiWEqIdx] = 0.0;
diff --git a/tutorial/tutorialspatialparameters_coupled.hh b/tutorial/tutorialspatialparameters_coupled.hh
index 3503de038ac9b0d3df7dd1e31e25cb1d75021846..283f8567203174b848b938fb988d02a7dd0e0dc5 100644
--- a/tutorial/tutorialspatialparameters_coupled.hh
+++ b/tutorial/tutorialspatialparameters_coupled.hh
@@ -96,7 +96,7 @@ public:
      *  on the position in the domain
      *
      *  \param element The finite volume element
      *  \param fvElemGeom The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *
      *  Alternatively, the function intrinsicPermeabilityAtPos(const GlobalPosition& globalPos)
@@ -104,15 +104,15 @@ public:
      *  of the finite volume.
      */
     const Dune::FieldMatrix<Scalar, dim, dim> &intrinsicPermeability(const Element &element, /*@\label{tutorial-coupled:permeability}@*/
-                                                    const FVElementGeometry &fvElemGeom,
-                                                    int scvIdx) const
+                                                    const FVElementGeometry &fvGeometry,
+                                                    const int scvIdx) const
     { return K_; }
 
     /*! Defines the porosity \f$[-]\f$ of the porous medium depending
      * on the position in the domain
      *
      *  \param element The finite volume element
      *  \param fvElemGeom The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *
      *  Alternatively, the function porosityAtPos(const GlobalPosition& globalPos)
@@ -120,15 +120,15 @@ public:
      *  of the finite volume.
      */
     Scalar porosity(const Element &element,                    /*@\label{tutorial-coupled:porosity}@*/
-                    const FVElementGeometry &fvElemGeom,
-                    int scvIdx) const
+                    const FVElementGeometry &fvGeometry,
+                    const int scvIdx) const
     { return 0.2; }
 
     /*! Returns the parameter object for the material law (i.e. Brooks-Corey)
      *  depending on the position in the domain
      *
      *  \param element The finite volume element
      *  \param fvElemGeom The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *
      *  Alternatively, the function materialLawParamsAtPos(const GlobalPosition& globalPos)
@@ -136,8 +136,8 @@ public:
      *  of the finite volume.
      */
     const MaterialLawParams& materialLawParams(const Element &element,            /*@\label{tutorial-coupled:matLawParams}@*/
-                                               const FVElementGeometry &fvElemGeom,
-                                               int scvIdx) const
+                                               const FVElementGeometry &fvGeometry,
+                                               const int scvIdx) const
     {
         return materialParams_;
     }
@@ -96,7 +96,7 @@ public:
      *
      *  \param element The finite volume element
-     *  \param fvElemGeom The finite-volume geometry in the box scheme
+     *  \param fvGeometry The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *
@@ -104,15 +104,15 @@ public:
      *
      *  \param element The finite volume element
-     *  \param fvElemGeom The finite-volume geometry in the box scheme
+     *  \param fvGeometry The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *
@@ -120,15 +120,15 @@ public:
      *
      *  \param element The finite volume element
-     *  \param fvElemGeom The finite-volume geometry in the box scheme
+     *  \param fvGeometry The finite-volume geometry in the box scheme
      *  \param scvIdx The local vertex index
      *